#pragma once

#include <iostream>
#include <sstream>
#include <iomanip>
#include <vector>
#include <string>

#ifdef __HIP__
#include "hip/hip_runtime.h"
#include "hip/hip_runtime_api.h"

static inline void HIP_CALL(hipError_t err) { 
    if (err != hipSuccess) { 
	throw std::runtime_error(hipGetErrorString(err)); 
    } 
    auto err_last = hipGetLastError(); 
    if (err_last != hipSuccess) { 
	throw std::runtime_error(hipGetErrorString(err_last)); 
    } 
}
#endif

static inline std::string rank2str(int rank) {
	return std::string("rank=") + std::to_string(rank) + ": ";
}

static inline void print(int rank, const std::string &str) {
    std::cout << rank2str(rank) << str << std::endl;
}

using real = double;

struct oglobal {
    std::string header;
    std::vector<double> values;
};

struct olocal {
    std::string header;
    std::vector<std::vector<double>> values;
};

